==> content_insights_report-1.0.6.tar.gz: content_insights_report/modules/content_insights_report_group/README.md <==
# Content Insights Report Group

This module generates a Content Insights Report per Group that provides
valuable data and analysis about the content in your system. The report
is based on various parameters, including content type, status, and
workflows, giving you insights into the overall performance and status
of the content within your system.


For a full description of the module on drupal.org, visit the
[project page](https://www.drupal.org/project/content_insights_report).

Submit bug reports and feature suggestions, or track changes in the
[issue queue](https://www.drupal.org/project/issues/search/content_insights_report).

## Table of contents

- Requirements
- Installation
- Configuration
- Maintainers

## Requirements

This module requires the following core modules:

- **group** Group module needs to be installed.
- **gnode** Group Node module needs to be installed.
- **node** Report is based on node content data.
- **content_moderation** Not required, but if module is enabled the data will
pull thru if settings is enabled for Moderation state.

## Installation

Install as you would normally install a contributed Drupal module. For further
information, see
[Installing Drupal Modules](https://www.drupal.org/docs/extending-drupal/installing-drupal-modules).
```bash
composer require drupal/content_insights_report
```

## Configuration

**Configuration:**

Navigate to Configuration > Content authoring > Content Insights Report using
the Admin Toolbar.

Alternatively, you can also use this link:
/admin/config/content/content_insights_report_group/settings

**Report:**

Navigate to Reports > Content Insights Report using the Admin Toolbar.

Alternatively, you can also use this link:
/admin/reports/content-insights-report

## Troubleshooting & FAQ


Q: Why can't I see the report?

A: It might be related to permissions.
Please follow the /admin/people/permissions/module/content_insights_report_group
to check the permissions.

## Maintainers

Current maintainers:

- [Kobus van Wyk (kobusvw)](https://www.drupal.org/u/kobusvw)

==> content_insights_report-1.0.8.tar.gz: content_insights_report/modules/content_insights_report_group/README.md <==
# Content Insights Report Group

This module generates a Content Insights Report per Group that provides
valuable data and analysis about the content in your system. The report
is based on various parameters, including content type, status, and
workflows, giving you insights into the overall performance and status
of the content within your system.


For a full description of the module on drupal.org, visit the
[project page](https://www.drupal.org/project/content_insights_report).

Submit bug reports and feature suggestions, or track changes in the
[issue queue](https://www.drupal.org/project/issues/search/content_insights_report).

## Table of contents

- Requirements
- Installation
- Configuration
- Troubleshooting & FAQ
- Maintainers
- Changelog

## Requirements

This module requires the following core modules:

- **group** Group module needs to be installed.
- **gnode** Group Node module needs to be installed.
- **node** Report is based on node content data.
- **content_moderation** Not required, but if module is enabled the data will
pull thru if settings is enabled for Moderation state.

## Installation

Install as you would normally install a contributed Drupal module. For further
information, see
[Installing Drupal Modules](https://www.drupal.org/docs/extending-drupal/installing-drupal-modules).
```bash
composer require drupal/content_insights_report
```

## Configuration

**Configuration:**

Navigate to Configuration > Content authoring > Content Insights Report using
the Admin Toolbar.

Alternatively, you can also use this link:
/admin/config/content/content_insights_report_group/settings

**Report:**

Navigate to Reports > Content Insights Report using the Admin Toolbar.

Alternatively, you can also use this link:
/admin/reports/content-insights-report

## Troubleshooting & FAQ

Q: Why can't I see the Group report?

A: It might be related to permissions.
Please follow the /admin/people/permissions/module/content_insights_report_group
to check the permissions.

## Maintainers

Current maintainers:

- [Kobus van Wyk (kobusvw)](https://www.drupal.org/u/kobusvw)

## Changelog

- **2025/03/09** - Add Total number of nodes, published and unpublished
- **2025/03/09** - Add Show/Hide on empty results (if no results are found, remove section from the report)
- **2025/03/09** - Change link to content to custom content page, Page will include date filters (created, changed & revision) Only Edit button will be available.
- **2025/03/09** - Add revision count to report
- **2025/03/09** - Change yes/no config fields to checkbox
- **2025/03/09** - Update styling of both reports.
